Codec

Trait Codec 

pub trait Codec<N: NestedValue> {
    // Required methods
    fn parse<'a, T: Parse<&'a Self, N>>(
        &'a self,
        value: &N,
    ) -> Result<T, ParseError>;
    fn unparse<'a, T: Unparse<&'a Self, N>>(&'a self, value: &T) -> N;
}
Every language implements Codec, which supplies convenient shorthand for invoking Parse::parse and Unparse::unparse.

Required Methods

fn parse<'a, T: Parse<&'a Self, N>>( &'a self, value: &N, ) -> Result<T, ParseError>

Delegates to T::parse, using self as language and the given value as input.

fn unparse<'a, T: Unparse<&'a Self, N>>(&'a self, value: &T) -> N

Delegates to value.unparse, using self as language.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<L, N: NestedValue> Codec<N> for L